==> fdordbms-3.2.2.tar.gz: OpenSource_FDO/Providers/GenericRdbms/Src/MySQL/SchemaMgr/Ph/ColumnByte.h <==
#ifndef FDOSMPHMYSQLCOLUMNBYTE_H
#define FDOSMPHMYSQLCOLUMNBYTE_H       1
/*
 * Copyright (C) 2004-2006  Autodesk, Inc.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 2.1 of the GNU Lesser
 * General Public License as published by the Free Software Foundation.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifdef _WIN32
#pragma once
#endif

#include <Inc/rdbi.h>
#include <Sm/Ph/ColumnByte.h>

// Represents a byte column, using the unsigned TINYINT MySql type. 
class FdoSmPhMySqlColumnByte :
    public FdoSmPhColumnByte, public FdoSmPhMySqlColumn
{
public:
    // Create a byte columntype.
    FdoSmPhMySqlColumnByte(
        FdoStringP columnName,
        FdoSchemaElementState elementState,
        FdoSmPhDbObject* parentObject,
        bool bNullable,
        FdoStringP rootColumnName = L"",
        FdoSmPhRdColumnReader* reader = NULL
    ) :
        FdoSmPhMySqlColumn (reader),
        FdoSmPhColumn    ( columnName, L"TINYINT UNSIGNED", elementState, parentObject, bNullable, rootColumnName)
    {}

    virtual ~FdoSmPhMySqlColumnByte(void) {}

    virtual int GetRdbType()
    {
        return RDBI_SHORT;
    }
};

typedef FdoPtr<FdoSmPhMySqlColumnByte> FdoSmPhMySqlColumnByteP;

#endif

==> fdordbms-3.3.2.tar.gz: OpenSource_FDO/Providers/GenericRdbms/Src/MySQL/SchemaMgr/Ph/ColumnByte.h <==
#ifndef FDOSMPHMYSQLCOLUMNBYTE_H
#define FDOSMPHMYSQLCOLUMNBYTE_H       1
/*
 * Copyright (C) 2004-2006  Autodesk, Inc.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 2.1 of the GNU Lesser
 * General Public License as published by the Free Software Foundation.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifdef _WIN32
#pragma once
#endif

#include <Inc/rdbi.h>
#include <Sm/Ph/ColumnByte.h>

// Represents a byte column, using the unsigned TINYINT MySql type. 
class FdoSmPhMySqlColumnByte :
    public FdoSmPhColumnByte, public FdoSmPhMySqlColumn
{
public:
    // Create a byte columntype.
    FdoSmPhMySqlColumnByte(
        FdoStringP columnName,
        FdoSchemaElementState elementState,
        FdoSmPhDbObject* parentObject,
        bool bNullable,
        FdoStringP rootColumnName = L"",
		FdoStringP defaultValue = L"",
        FdoSmPhRdColumnReader* reader = NULL
    ) :
        FdoSmPhMySqlColumn (reader),
        FdoSmPhColumn    ( columnName, L"TINYINT UNSIGNED", elementState, parentObject, bNullable, rootColumnName, defaultValue)
    {}

    virtual ~FdoSmPhMySqlColumnByte(void) {}

    virtual int GetRdbType()
    {
        return RDBI_SHORT;
    }
};

typedef FdoPtr<FdoSmPhMySqlColumnByte> FdoSmPhMySqlColumnByteP;

#endif
